@@ -13,10 +13,16 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_backup.literals import (
+    BackupJobState,
+    BackupVaultEvent,
+    ConditionType,
+    CopyJobState,
+    RecoveryPointStatus,
+    RestoreJobStatus,
+    StorageClass,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -103,9 +109,7 @@ BackupJobTypeDef = TypedDict(
         "ResourceArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "State": Literal[
-            "CREATED", "PENDING", "RUNNING", "ABORTING", "ABORTED", "COMPLETED", "FAILED", "EXPIRED"
-        ],
+        "State": BackupJobState,
         "StatusMessage": str,
         "PercentDone": str,
         "BackupSizeInBytes": int,
@@ -249,8 +253,7 @@ CalculatedLifecycleTypeDef = TypedDict(
 )
 
 ConditionTypeDef = TypedDict(
-    "ConditionTypeDef",
-    {"ConditionType": Literal["STRINGEQUALS"], "ConditionKey": str, "ConditionValue": str},
+    "ConditionTypeDef", {"ConditionType": ConditionType, "ConditionKey": str, "ConditionValue": str}
 )
 
 _RequiredCopyActionTypeDef = TypedDict(
@@ -277,7 +280,7 @@ CopyJobTypeDef = TypedDict(
         "ResourceArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "State": Literal["CREATED", "RUNNING", "COMPLETED", "FAILED"],
+        "State": CopyJobState,
         "StatusMessage": str,
         "BackupSizeInBytes": int,
         "IamRoleArn": str,
@@ -308,7 +311,7 @@ RecoveryPointByBackupVaultTypeDef = TypedDict(
         "ResourceType": str,
         "CreatedBy": "RecoveryPointCreatorTypeDef",
         "IamRoleArn": str,
-        "Status": Literal["COMPLETED", "PARTIAL", "DELETING", "EXPIRED"],
+        "Status": RecoveryPointStatus,
         "CreationDate": datetime,
         "CompletionDate": datetime,
         "BackupSizeInBytes": int,
@@ -326,7 +329,7 @@ RecoveryPointByResourceTypeDef = TypedDict(
     {
         "RecoveryPointArn": str,
         "CreationDate": datetime,
-        "Status": Literal["COMPLETED", "PARTIAL", "DELETING", "EXPIRED"],
+        "Status": RecoveryPointStatus,
         "EncryptionKeyArn": str,
         "BackupSizeBytes": int,
         "BackupVaultName": str,
@@ -359,7 +362,7 @@ RestoreJobsListMemberTypeDef = TypedDict(
         "RecoveryPointArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "Status": Literal["PENDING", "RUNNING", "COMPLETED", "ABORTED", "FAILED"],
+        "Status": RestoreJobStatus,
         "StatusMessage": str,
         "PercentDone": str,
         "BackupSizeInBytes": int,
@@ -444,9 +447,7 @@ DescribeBackupJobOutputTypeDef = TypedDict(
         "ResourceArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "State": Literal[
-            "CREATED", "PENDING", "RUNNING", "ABORTING", "ABORTED", "COMPLETED", "FAILED", "EXPIRED"
-        ],
+        "State": BackupJobState,
         "StatusMessage": str,
         "PercentDone": str,
         "BackupSizeInBytes": int,
@@ -515,7 +516,7 @@ DescribeRecoveryPointOutputTypeDef = TypedDict(
         "ResourceType": str,
         "CreatedBy": "RecoveryPointCreatorTypeDef",
         "IamRoleArn": str,
-        "Status": Literal["COMPLETED", "PARTIAL", "DELETING", "EXPIRED"],
+        "Status": RecoveryPointStatus,
         "CreationDate": datetime,
         "CompletionDate": datetime,
         "BackupSizeInBytes": int,
@@ -523,7 +524,7 @@ DescribeRecoveryPointOutputTypeDef = TypedDict(
         "Lifecycle": "LifecycleTypeDef",
         "EncryptionKeyArn": str,
         "IsEncrypted": bool,
-        "StorageClass": Literal["WARM", "COLD", "DELETED"],
+        "StorageClass": StorageClass,
         "LastRestoreTime": datetime,
         "ResponseMetadata": "ResponseMetadata",
     },
@@ -544,7 +545,7 @@ DescribeRestoreJobOutputTypeDef = TypedDict(
         "RecoveryPointArn": str,
         "CreationDate": datetime,
         "CompletionDate": datetime,
-        "Status": Literal["PENDING", "RUNNING", "COMPLETED", "ABORTED", "FAILED"],
+        "Status": RestoreJobStatus,
         "StatusMessage": str,
         "PercentDone": str,
         "BackupSizeInBytes": int,
@@ -622,25 +623,7 @@ GetBackupVaultNotificationsOutputTypeDef = TypedDict(
         "BackupVaultName": str,
         "BackupVaultArn": str,
         "SNSTopicArn": str,
-        "BackupVaultEvents": List[
-            Literal[
-                "BACKUP_JOB_STARTED",
-                "BACKUP_JOB_COMPLETED",
-                "BACKUP_JOB_SUCCESSFUL",
-                "BACKUP_JOB_FAILED",
-                "BACKUP_JOB_EXPIRED",
-                "RESTORE_JOB_STARTED",
-                "RESTORE_JOB_COMPLETED",
-                "RESTORE_JOB_SUCCESSFUL",
-                "RESTORE_JOB_FAILED",
-                "COPY_JOB_STARTED",
-                "COPY_JOB_SUCCESSFUL",
-                "COPY_JOB_FAILED",
-                "RECOVERY_POINT_MODIFIED",
-                "BACKUP_PLAN_CREATED",
-                "BACKUP_PLAN_MODIFIED",
-            ]
-        ],
+        "BackupVaultEvents": List[BackupVaultEvent],
         "ResponseMetadata": "ResponseMetadata",
     },
     total=False,
